@@ -1,9 +1,9 @@
 # IMPORTATION STANDARD
-import requests
 import logging
 from typing import Dict, Union
 
 # IMPORTATION THIRD PARTY
+import requests
 from google.protobuf import json_format
 
 # IMPORTATION INTERNAL
@@ -137,8 +137,10 @@ class ActionConfirmOrder(AbstractAction):
             response_raw = session.send(prepped, verify=False)
             response_raw.raise_for_status()
             response_dict = response_raw.json()
+        except requests.HTTPError as e:
+            logger.fatal(response_raw.status_code)
+            logger.fatal(response_raw.text)
         except Exception as e:
-            logger.fatal(response_raw)
             logger.fatal(e)
             return None
 
