@@ -44,8 +44,10 @@ class ActionDeleteOrder(AbstractAction):
         try:
             response_raw = session.send(prepped, verify=False)
             response_raw.raise_for_status()
+        except requests.HTTPError as e:
+            logger.fatal(response_raw.status_code)
+            logger.fatal(response_raw.text)
         except Exception as e:
-            logger.fatal(response_raw)
             logger.fatal(e)
             return None
 
