@@ -120,8 +120,10 @@ class ActionGetOrdersHistory(AbstractAction):
                 return cls.orders_history_to_grpc(
                     payload=response_dict,
                 )
+        except requests.HTTPError as e:
+            logger.fatal(response_raw.status_code)
+            logger.fatal(response_raw.text)
         except Exception as e:
-            logger.fatal(response_raw)
             logger.fatal(e)
             return None
 
