@@ -87,8 +87,10 @@ class ActionGetProductsConfig(AbstractAction):
                 return cls.products_config_to_grpc(
                     payload=response_dict,
                 )
+        except requests.HTTPError as e:
+            logger.fatal(response_raw.status_code)
+            logger.fatal(response_raw.text)
         except Exception as e:
-            logger.fatal(response_raw)
             logger.fatal(e)
             return None
 
