@@ -47,8 +47,10 @@ class ActionLogout(AbstractAction):
         try:
             response_raw = session.send(prepped, verify=False)
             response_raw.raise_for_status()
+        except requests.HTTPError as e:
+            logger.fatal(response_raw.status_code)
+            logger.fatal(response_raw.text)
         except Exception as e:
-            logger.fatal(response_raw)
             logger.fatal(e)
             return None
 
